@@ -17,14 +17,15 @@ import org.gnu.gtk.event.ColorButtonListener;
  * ColorButtonListener delegate class.
  */
 public class ColorButtonDelegate extends ListenerDelegate implements
-		ColorButtonListener {
+        ColorButtonListener {
 
-	public ColorButtonDelegate(String signal, Object owner, Method handler, Object target) throws NoSuchMethodException {
-		super(signal, owner, handler, target);
-	}
+    public ColorButtonDelegate(String signal, Object owner, Method handler,
+            Object target) throws NoSuchMethodException {
+        super(signal, owner, handler, target);
+    }
 
-	public boolean colorButtonEvent(ColorButtonEvent event) {
-		return fireEvent(event);
-	}
+    public boolean colorButtonEvent(ColorButtonEvent event) {
+        return fireEvent(event);
+    }
 
 }
