@@ -17,13 +17,14 @@ import org.gnu.gtk.event.ExpanderListener;
  * ToolBarListener delegate class.
  */
 public class ExpanderDelegate extends ListenerDelegate implements
-		ExpanderListener {
+        ExpanderListener {
 
-	public ExpanderDelegate(String signal, Object owner, Method handler, Object target) throws NoSuchMethodException {
-		super(signal, owner, handler, target);
-	}
+    public ExpanderDelegate(String signal, Object owner, Method handler,
+            Object target) throws NoSuchMethodException {
+        super(signal, owner, handler, target);
+    }
 
-	public boolean expanderEvent(ExpanderEvent event) {
-		return fireEvent(event);
-	}
+    public boolean expanderEvent(ExpanderEvent event) {
+        return fireEvent(event);
+    }
 }
